summaryrefslogtreecommitdiff
path: root/lib/savedir.c
diff options
context:
space:
mode:
authorJim Meyering <jim@meyering.net>1994-07-30 12:10:53 +0000
committerJim Meyering <jim@meyering.net>1994-07-30 12:10:53 +0000
commitf1f85daaed8685b8a15c243c95bb7341e0fb5fe1 (patch)
tree831a3c427a01929862bbb50415149143b7741063 /lib/savedir.c
parent88494fb8f3b4d038d9d25b2624bf268837722c09 (diff)
downloadcoreutils-f1f85daaed8685b8a15c243c95bb7341e0fb5fe1.tar.xz
.
Diffstat (limited to 'lib/savedir.c')
-rw-r--r--lib/savedir.c41
1 files changed, 27 insertions, 14 deletions
diff --git a/lib/savedir.c b/lib/savedir.c
index fce61da0d..b831c1fe9 100644
--- a/lib/savedir.c
+++ b/lib/savedir.c
@@ -15,28 +15,41 @@
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. */
-/* Written by David MacKenzie <djm@ai.mit.edu>. */
+/* Written by David MacKenzie <djm@gnu.ai.mit.edu>. */
+
+#ifdef HAVE_CONFIG_H
+#if defined (CONFIG_BROKETS)
+/* We use <config.h> instead of "config.h" so that a compilation
+ using -I. -I$srcdir will use ./config.h rather than $srcdir/config.h
+ (which it would do because it found this file in $srcdir). */
+#include <config.h>
+#else
+#include "config.h"
+#endif
+#endif
#include <sys/types.h>
+
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
#ifdef DIRENT
#include <dirent.h>
-#ifdef direct
-#undef direct
-#endif
-#define direct dirent
#define NLENGTH(direct) (strlen((direct)->d_name))
-#else
+#else /* not DIRENT */
+#define dirent direct
#define NLENGTH(direct) ((direct)->d_namlen)
-#ifdef USG
#ifdef SYSNDIR
#include <sys/ndir.h>
-#else
-#include <ndir.h>
-#endif
-#else
+#endif /* SYSNDIR */
+#ifdef SYSDIR
#include <sys/dir.h>
-#endif
-#endif
+#endif /* SYSDIR */
+#ifdef NDIR
+#include <ndir.h>
+#endif /* NDIR */
+#endif /* DIRENT */
#ifdef VOID_CLOSEDIR
/* Fake a return value. */
@@ -71,7 +84,7 @@ savedir (dir, name_size)
unsigned name_size;
{
DIR *dirp;
- struct direct *dp;
+ struct dirent *dp;
char *name_space;
char *namep;